#######
euporie
#######

|PyPI| |RTD| |Binder| |License| |Stars|

.. content_start

**Euporie is a text-based user interface for running and editing Jupyter notebooks.**

The interface is similar to JupyterLab or Jupyter Notebook, and supports keyboard or mouse navigation.

View the online documentation at: `https://euporie.readthedocs.io/ <https://euporie.readthedocs.io/>`_

----

.. image:: https://user-images.githubusercontent.com/12154190/151821363-9176faac-169f-4b12-a83f-8a4004e5b9bb.png
   :target: https://user-images.githubusercontent.com/12154190/151821363-9176faac-169f-4b12-a83f-8a4004e5b9bb.png

`View more screenshots here <https://euporie.readthedocs.io/en/latest/pages/gallery.html>`_

*******
Install
*******

You can install euporie with `pipx <pipxproject.github.io/>`_:

.. code-block:: console

   $ pipx install euporie

You can also try euporie online `here <https://mybinder.org/v2/gh/joouha/euporie-binder/HEAD?urlpath=%2Feuporie%2F>`_.

********
Features
********

* Edit and run notebooks in the terminal
* Open multiple notebooks
* Code completion
* Suggests line completions from history
* Hightly configurable
* Print formatted notebooks to the terminal or pager
* Displays rich cell outputs, including:

   * Markdown
   * Tables
   * Images
   * LaTeX
   * HTML
   * SVG

*************
Compatibility
*************

Euporie requires Python 3.8 or later. It works on Linux, Windows and MacOS



.. |PyPI| image:: https://img.shields.io/pypi/v/euporie.svg
    :target: https://pypi.python.org/project/euporie/
    :alt: Latest Version

.. |RTD| image:: https://readthedocs.org/projects/euporie/badge/
    :target: https://euporie.readthedocs.io/en/latest/
    :alt: Documentation

.. |Binder| image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/joouha/euporie-binder/HEAD?urlpath=%2Feuporie%2F
   :alt: Launch with Binder

.. |License| image:: https://img.shields.io/github/license/joouha/euporie.svg
    :target: https://github.com/joouha/euporie/blob/main/LICENSE
    :alt: View license

.. |Stars| image:: https://img.shields.io/github/stars/joouha/euporie
    :target: https://github.com/joouha/euporie/stargazers
    :alt: ⭐
